HeatTreeWidget

HeatTreeWidget(html, embed, env)

An interactive phylogenetic tree widget.

This object uses the _repr_html_ protocol so it is automatically rendered when it is the last expression in a Jupyter notebook cell.

Attributes

Name Type Description
_embed Whether the widget was created with embed=True.
_env The detected environment (“jupyter”, “ipython”, or “plain”).
_temp_path Path to the temporary file if show() was called.

Methods

Name Description
save Save as a standalone HTML file.
show Open the widget in a web browser.
to_html Return the raw HTML string.

save

HeatTreeWidget.save(path)

Save as a standalone HTML file.

show

HeatTreeWidget.show()

Open the widget in a web browser.

Saves the widget to a temporary HTML file and opens it in the default web browser. The file path is printed to stdout.

Returns

Name Type Description
pathlib.Path: Path to the saved temporary HTML file.

to_html

HeatTreeWidget.to_html()

Return the raw HTML string.